# coinceres -- CoinCeres SDK

## Usage

### Install

```pip install coinceres```

### Example

```python

import coinceres

connection = coinceres.APIClient(api_key="api_key", secret_key="secret")
connection.account()

```
